"use strict";
/*
 * Kuzzle, a backend software, self-hostable and ready to use
 * to power modern apps
 *
 * Copyright 2015-2022 Kuzzle
 * mailto: support AT kuzzle.io
 * website: http://kuzzle.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenApiManager = void 0;
const package_json_1 = require("../../../package.json");
const openApiGenerator_1 = require("./openApiGenerator");
class OpenApiManager {
    /**
     * @param applicationDefinition Application OpenApi definition
     * @param pluginsManager PluginsManager instance
     */
    constructor(applicationDefinition, kuzzleRoutes, pluginsRoutes) {
        /* eslint-disable sort-keys */
        this.kuzzleDefinition = {
            swagger: "2.0",
            info: {
                title: "Kuzzle API",
                description: "Kuzzle HTTP API definition",
                contact: {
                    name: "Kuzzle team",
                    url: "https://kuzzle.io",
                    email: "support@kuzzle.io",
                },
                license: {
                    name: "Apache 2",
                    url: "http://opensource.org/licenses/apache2.0",
                },
                version: package_json_1.version,
            },
            externalDocs: {
                description: "Kuzzle API Documentation",
                url: "https://docs.kuzzle.io/core/2/api/",
            },
            tags: [],
            schemes: ["https", "http"],
            paths: {},
        };
        this.applicationDefinition = applicationDefinition;
        (0, openApiGenerator_1.generateOpenApi)(kuzzleRoutes, this.kuzzleDefinition);
        (0, openApiGenerator_1.generateOpenApi)(pluginsRoutes, this.applicationDefinition);
        this.registerAskEvents();
    }
    registerAskEvents() {
        global.kuzzle.onAsk("core:api:openapi:kuzzle", () => this.kuzzleDefinition);
        global.kuzzle.onAsk("core:api:openapi:app", () => this.applicationDefinition);
    }
}
exports.OpenApiManager = OpenApiManager;
//# sourceMappingURL=OpenApiManager.js.map