/**
 * Allows to define an authentication strategy
 */
export type StrategyDefinition = {
    /**
     * Strategy name and definition.
     */
    [name: string]: {
        /**
         * Strategy configuration.
         */
        config: {
            /**
             * Name of a registered authenticator to use with this strategy.
             */
            authenticator: string;
            [key: string]: any;
        };
        /**
         * Strategy methods.
         *
         * Each method must be exposed by the plugin
         * under the same name as specified.
         */
        methods: {
            afterRegister?: string;
            create: string;
            delete: string;
            exists: string;
            getById?: string;
            getInfo?: string;
            search?: string;
            update: string;
            validate: string;
            verify: string;
        };
    };
};
