export type GenerateRandomNameOpts = {
    /**
     * Optional prefix.
     */
    prefix?: string;
    /**
     * Optional separator. Defaults to `-`.
     */
    separator?: string;
    /**
     * Optional postfix random number range. Set to `false` to disable postfix. Defaults to `{ min: 0, max: 100000 }`
     */
    postfixRandRange?: {
        /**
         * Optional minimum postfix random number (inclusive). Defaults to `0`.
         */
        min?: number;
        /**
         * Maximum postfix random number (exclusive).
         */
        max: number;
    } | false;
};
export declare class NameGenerator {
    /**
     * Returns a random name.
     *
     * # Usage:
     *
     * ```js
     * const name = NameGenerator.getRandomName(); // 'verdi'
     * ```
     *
     * @returns a random name
     */
    static getRandomName(): string;
    /**
     * Returns a random adjective.
     *
     * # Usage
     *
     * ```js
     * const adj = NameGenerator.getRandomAdjective(); // 'absent'
     * ```
     *
     * @returns a random adjective
     */
    static getRandomAdjective(): string;
    /**
     * Generates a random formatted name that consists of an optional prefix, a random adjective,
     * a random name and an optional random number separated by separator (default: '-').
     *
     * Format: `[prefix<separator>]<adjective><separator><name>[<separator>random number]`
     *
     * Format example: `something-dashing-euler-1164`
     *
     * ## Usage
     *
     * ```js
     * let name = NameGenerator.generateRandomName({
     *   prefix: 'my',
     *   separator: '_',
     *   postfixRandRange: { min: 1, max: 10 }
     * }); // 'my_abandoned_yogi_5'
     *
     * name = NameGenerator.generateRandomName({
     *   separator: ' ',
     *   postfixRandRange: false
     * }); // 'amused vampire'
     * ```
     *
     * @param {GenerateRandomNameOpts} opts Optional options
     *
     * @returns a random formatted name
     */
    static generateRandomName({ prefix, separator, postfixRandRange, }?: GenerateRandomNameOpts): string;
}
export declare function randomNumber(max: number): number;
export declare function randomNumber(min: number, max: number): number;
